Instrument class
================


hardware_control.base.Instrument module
---------------------------------------

.. automodule:: hardware_control.base.Instrument
   :members:
   :undoc-members:
   :show-inheritance:

